pitchtools.ObjectSet
====================

.. inheritance-diagram:: abjad.tools.pitchtools.ObjectSet.ObjectSet.ObjectSet
   :private-bases:

.. autoclass:: abjad.tools.pitchtools.ObjectSet.ObjectSet.ObjectSet

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.pitchtools.ObjectSet.ObjectSet.ObjectSet.storage_format

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

Methods
-------

.. automethod:: abjad.tools.pitchtools.ObjectSet.ObjectSet.ObjectSet.copy

    Inherited from :py:class:`__builtin__.frozenset`

.. automethod:: abjad.tools.pitchtools.ObjectSet.ObjectSet.ObjectSet.difference

    Inherited from :py:class:`__builtin__.frozenset`

.. automethod:: abjad.tools.pitchtools.ObjectSet.ObjectSet.ObjectSet.intersection

    Inherited from :py:class:`__builtin__.frozenset`

.. automethod:: abjad.tools.pitchtools.ObjectSet.ObjectSet.ObjectSet.isdisjoint

    Inherited from :py:class:`__builtin__.frozenset`

.. automethod:: abjad.tools.pitchtools.ObjectSet.ObjectSet.ObjectSet.issubset

    Inherited from :py:class:`__builtin__.frozenset`

.. automethod:: abjad.tools.pitchtools.ObjectSet.ObjectSet.ObjectSet.issuperset

    Inherited from :py:class:`__builtin__.frozenset`

.. automethod:: abjad.tools.pitchtools.ObjectSet.ObjectSet.ObjectSet.symmetric_difference

    Inherited from :py:class:`__builtin__.frozenset`

.. automethod:: abjad.tools.pitchtools.ObjectSet.ObjectSet.ObjectSet.union

    Inherited from :py:class:`__builtin__.frozenset`

Special Methods
---------------

.. automethod:: abjad.tools.pitchtools.ObjectSet.ObjectSet.ObjectSet.__and__

    Inherited from :py:class:`__builtin__.frozenset`

.. automethod:: abjad.tools.pitchtools.ObjectSet.ObjectSet.ObjectSet.__cmp__

    Inherited from :py:class:`__builtin__.frozenset`

.. automethod:: abjad.tools.pitchtools.ObjectSet.ObjectSet.ObjectSet.__contains__

    Inherited from :py:class:`__builtin__.frozenset`

.. automethod:: abjad.tools.pitchtools.ObjectSet.ObjectSet.ObjectSet.__eq__

    Inherited from :py:class:`__builtin__.frozenset`

.. automethod:: abjad.tools.pitchtools.ObjectSet.ObjectSet.ObjectSet.__ge__

    Inherited from :py:class:`__builtin__.frozenset`

.. automethod:: abjad.tools.pitchtools.ObjectSet.ObjectSet.ObjectSet.__gt__

    Inherited from :py:class:`__builtin__.frozenset`

.. automethod:: abjad.tools.pitchtools.ObjectSet.ObjectSet.ObjectSet.__hash__

    Inherited from :py:class:`__builtin__.frozenset`

.. automethod:: abjad.tools.pitchtools.ObjectSet.ObjectSet.ObjectSet.__iter__

    Inherited from :py:class:`__builtin__.frozenset`

.. automethod:: abjad.tools.pitchtools.ObjectSet.ObjectSet.ObjectSet.__le__

    Inherited from :py:class:`__builtin__.frozenset`

.. automethod:: abjad.tools.pitchtools.ObjectSet.ObjectSet.ObjectSet.__len__

    Inherited from :py:class:`__builtin__.frozenset`

.. automethod:: abjad.tools.pitchtools.ObjectSet.ObjectSet.ObjectSet.__lt__

    Inherited from :py:class:`__builtin__.frozenset`

.. automethod:: abjad.tools.pitchtools.ObjectSet.ObjectSet.ObjectSet.__ne__

    Inherited from :py:class:`__builtin__.frozenset`

.. automethod:: abjad.tools.pitchtools.ObjectSet.ObjectSet.ObjectSet.__or__

    Inherited from :py:class:`__builtin__.frozenset`

.. automethod:: abjad.tools.pitchtools.ObjectSet.ObjectSet.ObjectSet.__rand__

    Inherited from :py:class:`__builtin__.frozenset`

.. automethod:: abjad.tools.pitchtools.ObjectSet.ObjectSet.ObjectSet.__repr__

    Inherited from :py:class:`__builtin__.frozenset`

.. automethod:: abjad.tools.pitchtools.ObjectSet.ObjectSet.ObjectSet.__ror__

    Inherited from :py:class:`__builtin__.frozenset`

.. automethod:: abjad.tools.pitchtools.ObjectSet.ObjectSet.ObjectSet.__rsub__

    Inherited from :py:class:`__builtin__.frozenset`

.. automethod:: abjad.tools.pitchtools.ObjectSet.ObjectSet.ObjectSet.__rxor__

    Inherited from :py:class:`__builtin__.frozenset`

.. automethod:: abjad.tools.pitchtools.ObjectSet.ObjectSet.ObjectSet.__sub__

    Inherited from :py:class:`__builtin__.frozenset`

.. automethod:: abjad.tools.pitchtools.ObjectSet.ObjectSet.ObjectSet.__xor__

    Inherited from :py:class:`__builtin__.frozenset`
